@@ -3,7 +3,7 @@
 
 #include <QMainWindow>
 #include <QSettings>
-class MainWindow;
+class MaemoBarcodeWindow;
 namespace Ui {
     class SettingsWindow;
 }
@@ -11,20 +11,20 @@ namespace Ui {
 class SettingsWindow : public QMainWindow {
     Q_OBJECT
 public:
-    SettingsWindow(QWidget *parent = 0);
+    SettingsWindow(MaemoBarcodeWindow *parent = 0);
     ~SettingsWindow();
-    void setSettings(QSettings *settings);
 protected:
     void changeEvent(QEvent *e);
-
+    void hideEvent(QHideEvent *);
+    void showEvent(QShowEvent *);
 private:
     QSettings *settings;
     Ui::SettingsWindow *ui;
+    MaemoBarcodeWindow *parent;
 
 private slots:
     void on_spnAutoFocusDelay_valueChanged(double );
     void on_chkSaveHistory_clicked();
-    void on_chkFullscreenScan_clicked();
 };
 
 #endif // SETTINGSWINDOW_H
